==> browser-eal_0.5.1-5.3%2b0m5.tar.gz: browser-eal-0.5.1/src/gwebengine.c <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the EAL package.
 *
 * The Initial Developer of the Original Code is Nokia Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contact: Leonid Zolotarev <leonid.zolotarev@nokia.com>
 *
 * ***** END LICENSE BLOCK ***** */

#include "gwebengine.h"

static void
g_web_engine_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		/* create interface signals here. */
		initialized = TRUE;
	}
}

GType
g_web_engine_get_type (void)
{
    static GType type = 0;
    if (type == 0) {
        static const GTypeInfo info = {
            sizeof (GWebEngineIface),
            g_web_engine_base_init,   /* base_init */
            NULL,   /* base_finalize */
            NULL,   /* class_init */
            NULL,   /* class_finalize */
            NULL,   /* class_data */
            0,
            0,      /* n_preallocs */
            NULL    /* instance_init */
        };
        type = g_type_register_static (G_TYPE_INTERFACE, "GWebEngine", &info, 0);
    }
    return type;
}

void
g_web_engine_destroy (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->destroy (self);
}

void
g_web_engine_reset (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->reset (self);
}

gboolean
g_web_engine_realize_window (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->realize_window (self);
}

void
g_web_engine_load_url (GWebEngine *self, const gchar *url)
{
	G_WEB_ENGINE_GET_CLASS (self)->load_url (self, url);
}

GWebStatus
g_web_engine_load_follow_link (GWebEngine *self, const gchar *url)
{
	return G_WEB_ENGINE_GET_CLASS (self)->load_follow_link (self, url);
}

GWebStatus
g_web_engine_load_url_with_css (GWebEngine *self, const gchar *url, const gchar *cssfile)
{
	return G_WEB_ENGINE_GET_CLASS (self)->load_url_with_css (self, url, cssfile);
}

void
g_web_engine_load_url_with_js (GWebEngine *self, gboolean  enable)
{
	G_WEB_ENGINE_GET_CLASS (self)->load_url_with_js (self, enable);
}

void
g_web_engine_load_home_page (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->load_home_page (self);
}

void
g_web_engine_stop_load (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->stop_load (self);
}

void
g_web_engine_reload (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->reload (self);
}

void
g_web_engine_go_back (GWebEngine *self, guint nsteps)
{
	G_WEB_ENGINE_GET_CLASS (self)->go_back (self, nsteps);
}

void
g_web_engine_go_forward (GWebEngine *self, guint nsteps)
{
	G_WEB_ENGINE_GET_CLASS (self)->go_forward (self, nsteps);
}

gboolean
g_web_engine_can_go_back (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_go_back (self);
}

gboolean
g_web_engine_can_go_forward (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_go_forward (self);
}

void
g_web_engine_zoom_by_steps (GWebEngine *self, guint relative_zoom, guint* legal_zoom_value)
{
	G_WEB_ENGINE_GET_CLASS (self)->zoom_by_steps (self, relative_zoom, legal_zoom_value);
}

void
g_web_engine_new_zoom_by_steps (GWebEngine *self, gboolean up, guint* legal_zoom_value)
{
	G_WEB_ENGINE_GET_CLASS (self)->new_zoom_by_steps (self, up, legal_zoom_value);
}

void
g_web_engine_set_zoom_level (GWebEngine *self, gint level)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_zoom_level (self, level);
}


GWebStatus
g_web_engine_set_zoom_level_around_point (GWebEngine *self, guint x, guint y, gint level)
{
	return G_WEB_ENGINE_GET_CLASS (self)->set_zoom_level_around_point (self, x, y, level);
}

GWebStatus
g_web_engine_compare_frames_zoom_level (GWebEngine *self, gboolean *equal)
{
	return G_WEB_ENGINE_GET_CLASS (self)->compare_frames_zoom_level (self, equal);
}

GWebStatus
g_web_engine_get_image_properties (GWebEngine *self, const gchar *url, gchar **file_type, guint *file_size, guint *width, guint *height)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_image_properties (self, url, file_type, file_size, width, height);
}

GWebStatus
g_web_engine_get_frame_properties (GWebEngine *self, gchar **file_type, guint *file_size, GWebEngineEncoding *file_encoding, guint *security, gboolean *automatic_encoding)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_properties (self, file_type, file_size, file_encoding, security, automatic_encoding);
}

GWebStatus
g_web_engine_load_image (GWebEngine *self, const gchar* url)
{
	return G_WEB_ENGINE_GET_CLASS (self)->load_image (self, url);
}

gint
g_web_engine_get_back_window_history_list (GWebEngine *self, GWebHistoryList **history)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_back_window_history_list (self, history);
}

gint
g_web_engine_get_forward_window_history_list (GWebEngine *self, GWebHistoryList **history)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_forward_window_history_list (self, history);
}

guint
g_web_engine_get_zoom_level (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_zoom_level (self);
}

void
g_web_engine_set_frame_zoom_level (GWebEngine *self, guint level)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_frame_zoom_level (self, level);
}

guint
g_web_engine_get_frame_zoom_level (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_zoom_level (self);
}

void
g_web_engine_set_layout_mode (GWebEngine *self, GWebEngineLayoutMode mode)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_layout_mode (self, mode);
}

GWebEngineLayoutMode
g_web_engine_get_layout_mode (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_layout_mode (self);
}

void
g_web_engine_set_load_images (GWebEngine *self, GWebEngineImagePolicy level)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_load_images (self, level);
}

GWebEngineImagePolicy
g_web_engine_get_load_images (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_load_images (self);
}

void
g_web_engine_set_frame_stacking (GWebEngine *self, gboolean enabled)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_frame_stacking (self, enabled);
}

gboolean
g_web_engine_get_frame_stacking (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_stacking (self);
}

GWebStatus
g_web_engine_save_web_page (GWebEngine *self, GWebEngineSaveAction setting, const gchar *file_name_with_path)
{
	return G_WEB_ENGINE_GET_CLASS (self)->save_web_page (self, setting, file_name_with_path);
}

GWebStatus
g_web_engine_save_current_frame (GWebEngine *self, GWebEngineSaveAction setting, const gchar *file_name_with_path)
{
	return G_WEB_ENGINE_GET_CLASS (self)->save_current_frame (self, setting, file_name_with_path);
}

gchar*
g_web_engine_get_frame_title (GWebEngine *self, gint frame_number)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_title (self, frame_number);
}

gchar* 
g_web_engine_get_element_details (GWebEngine *self, gint type)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_element_details (self, type);
}

gint
g_web_engine_get_frame_number (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_number (self);
}

GWebStatus
g_web_engine_save_web_page_image (GWebEngine *self, const gchar *url, const gchar* directory)
{
	return G_WEB_ENGINE_GET_CLASS (self)->save_web_page_image (self, url, directory);
}

void
g_web_engine_select_all_text (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->select_all_text (self);
}

void
g_web_engine_set_language_encoding (GWebEngine *self, GWebEngineEncoding encoding)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_language_encoding (self, encoding);
}

void
g_web_engine_set_frame_encoding (GWebEngine *self, GWebEngineEncoding encoding)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_frame_encoding (self, encoding);
}

gboolean
g_web_engine_find_text (GWebEngine *self, const gchar *string, gboolean reverse, gboolean whole_word, gboolean case_sensitive, gboolean restart)
{
	return G_WEB_ENGINE_GET_CLASS (self)->find_text (self, string, reverse, whole_word, case_sensitive, restart);
}

void
g_web_engine_authenticate (GWebEngine *self, gboolean ok, const gchar *username, const gchar *password)
{
	G_WEB_ENGINE_GET_CLASS (self)->authenticate (self, ok, username, password);
}

GWebStatus
g_web_engine_cut (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->cut (self);
}

GWebStatus
g_web_engine_copy (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->copy (self);
}

GWebStatus
g_web_engine_paste (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->paste (self);
}

gboolean
g_web_engine_can_cut (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_cut (self);
}

gboolean
g_web_engine_can_paste (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_paste (self);
}

gboolean
g_web_engine_can_copy (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_copy (self);
}

gboolean
g_web_engine_can_selecttext (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_selecttext (self);
}

gchar*
g_web_engine_get_favicon_name (GWebEngine *self, const gchar *favicon_folder)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_favicon_name (self, favicon_folder);
}

GObject*
g_web_engine_get_engine_widget (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_engine_widget (self);
}

GObject*
g_web_engine_get_engine_notifier (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_engine_notifier (self);
}

void
g_web_engine_set_open_link_mode (GWebEngine *self, gboolean in_new_window)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_open_link_mode (self, in_new_window);
}

GWebStatus
g_web_engine_set_true_zoom_mode (GWebEngine *self, gboolean status)
{
	return G_WEB_ENGINE_GET_CLASS (self)->set_true_zoom_mode (self, status);
}

void
g_web_engine_notify_plugins (GWebEngine *self, gint event)
{
	G_WEB_ENGINE_GET_CLASS (self)->notify_plugins (self, event);
}

void
g_web_engine_preload_current_skin (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->preload_current_skin (self);
}
void
g_web_engine_invoke_selectmatch (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->invoke_selectmatch (self);
}

GArray*
g_web_engine_get_server_certificate (GWebEngine *self, gpointer context)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_server_certificate (self, context);
}

gchar* 
g_web_engine_get_page_verifier_name( GWebEngine *self )
{
    return G_WEB_ENGINE_GET_CLASS (self)->get_page_verifier_name (self);
}

gboolean
g_web_engine_permit_page_unload (GWebEngine *self, glong time_sec, glong time_usec, glong timeout_usec, guint *timeout_id)
{
    return G_WEB_ENGINE_GET_CLASS (self)->permit_page_unload (self, time_sec, time_usec, timeout_usec);
}



gboolean 
g_web_engine_get_thumbnail (GWebEngine *self, const gchar* thumbnail_filename, gint width, gint height)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_thumbnail (self, thumbnail_filename, width, height );
}

gint
g_web_engine_get_text_zoom_level(GWebEngine *self)
{
    return G_WEB_ENGINE_GET_CLASS(self)->get_text_zoom_level(self);
}

void
g_web_engine_set_text_zoom_level(GWebEngine *self, gint zoom_level)
{
    G_WEB_ENGINE_GET_CLASS(self)->set_text_zoom_level(self, zoom_level);
}


void 
g_web_engine_enable_shistory_thumbnails (GWebEngine *self, gboolean enable, gint width, gint height)
{
	return G_WEB_ENGINE_GET_CLASS (self)->enable_shistory_thumbnails (self, enable, width, height );
}

void
g_web_engine_update_area (GWebEngine *self, int id, int top, int left, int width, int height, int zoom)
{
	G_WEB_ENGINE_GET_CLASS (self)->update_area (self, id, top, left, width, height, zoom);
}

void
g_web_engine_send_mouse_event (GWebEngine *self, int type, int x, int y, int mod, int button, int clickcount, int time)
{
	G_WEB_ENGINE_GET_CLASS (self)->send_mouse_event (self, type, x, y, mod, button, clickcount, time);
}

gboolean 
g_web_engine_evaluate_js (GWebEngine *self, const gchar* js)
{
	return G_WEB_ENGINE_GET_CLASS (self)->evaluate_js (self, js );
}

==> browser-eal_0.5.5-6.6%2b0m5.tar.gz: browser-eal-0.5.5/src/gwebengine.c <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the EAL package.
 *
 * The Initial Developer of the Original Code is Nokia Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contact: Leonid Zolotarev <leonid.zolotarev@nokia.com>
 *
 * ***** END LICENSE BLOCK ***** */

#include "gwebengine.h"

static void
g_web_engine_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized) {
		/* create interface signals here. */
		initialized = TRUE;
	}
}

GType
g_web_engine_get_type (void)
{
    static GType type = 0;
    if (type == 0) {
        static const GTypeInfo info = {
            sizeof (GWebEngineIface),
            g_web_engine_base_init,   /* base_init */
            NULL,   /* base_finalize */
            NULL,   /* class_init */
            NULL,   /* class_finalize */
            NULL,   /* class_data */
            0,
            0,      /* n_preallocs */
            NULL    /* instance_init */
        };
        type = g_type_register_static (G_TYPE_INTERFACE, "GWebEngine", &info, 0);
    }
    return type;
}

void
g_web_engine_destroy (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->destroy (self);
}

void
g_web_engine_reset (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->reset (self);
}

gboolean
g_web_engine_realize_window (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->realize_window (self);
}

void
g_web_engine_load_url (GWebEngine *self, const gchar *url)
{
	G_WEB_ENGINE_GET_CLASS (self)->load_url (self, url);
}

GWebStatus
g_web_engine_load_follow_link (GWebEngine *self, const gchar *url)
{
	return G_WEB_ENGINE_GET_CLASS (self)->load_follow_link (self, url);
}

GWebStatus
g_web_engine_load_url_with_css (GWebEngine *self, const gchar *url, const gchar *cssfile)
{
	return G_WEB_ENGINE_GET_CLASS (self)->load_url_with_css (self, url, cssfile);
}

void
g_web_engine_load_url_with_js (GWebEngine *self, gboolean  enable)
{
	G_WEB_ENGINE_GET_CLASS (self)->load_url_with_js (self, enable);
}

void
g_web_engine_load_home_page (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->load_home_page (self);
}

void
g_web_engine_stop_load (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->stop_load (self);
}

void
g_web_engine_reload (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->reload (self);
}

void
g_web_engine_go_back (GWebEngine *self, guint nsteps)
{
	G_WEB_ENGINE_GET_CLASS (self)->go_back (self, nsteps);
}

void
g_web_engine_go_forward (GWebEngine *self, guint nsteps)
{
	G_WEB_ENGINE_GET_CLASS (self)->go_forward (self, nsteps);
}

gboolean
g_web_engine_can_go_back (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_go_back (self);
}

gboolean
g_web_engine_can_go_forward (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_go_forward (self);
}

void
g_web_engine_zoom_by_steps (GWebEngine *self, guint relative_zoom, guint* legal_zoom_value)
{
	G_WEB_ENGINE_GET_CLASS (self)->zoom_by_steps (self, relative_zoom, legal_zoom_value);
}

void
g_web_engine_new_zoom_by_steps (GWebEngine *self, gboolean up, guint* legal_zoom_value)
{
	G_WEB_ENGINE_GET_CLASS (self)->new_zoom_by_steps (self, up, legal_zoom_value);
}

void
g_web_engine_set_zoom_level (GWebEngine *self, gint level)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_zoom_level (self, level);
}


GWebStatus
g_web_engine_set_zoom_level_around_point (GWebEngine *self, guint x, guint y, gint level)
{
	return G_WEB_ENGINE_GET_CLASS (self)->set_zoom_level_around_point (self, x, y, level);
}

GWebStatus
g_web_engine_compare_frames_zoom_level (GWebEngine *self, gboolean *equal)
{
	return G_WEB_ENGINE_GET_CLASS (self)->compare_frames_zoom_level (self, equal);
}

GWebStatus
g_web_engine_get_image_properties (GWebEngine *self, const gchar *url, gchar **file_type, guint *file_size, guint *width, guint *height)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_image_properties (self, url, file_type, file_size, width, height);
}

GWebStatus
g_web_engine_get_frame_properties (GWebEngine *self, gchar **file_type, guint *file_size, GWebEngineEncoding *file_encoding, guint *security, gboolean *automatic_encoding)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_properties (self, file_type, file_size, file_encoding, security, automatic_encoding);
}

GWebStatus
g_web_engine_load_image (GWebEngine *self, const gchar* url)
{
	return G_WEB_ENGINE_GET_CLASS (self)->load_image (self, url);
}

gint
g_web_engine_get_back_window_history_list (GWebEngine *self, GWebHistoryList **history)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_back_window_history_list (self, history);
}

gint
g_web_engine_get_forward_window_history_list (GWebEngine *self, GWebHistoryList **history)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_forward_window_history_list (self, history);
}

guint
g_web_engine_get_zoom_level (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_zoom_level (self);
}

void
g_web_engine_set_frame_zoom_level (GWebEngine *self, guint level)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_frame_zoom_level (self, level);
}

guint
g_web_engine_get_frame_zoom_level (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_zoom_level (self);
}

void
g_web_engine_set_layout_mode (GWebEngine *self, GWebEngineLayoutMode mode)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_layout_mode (self, mode);
}

GWebEngineLayoutMode
g_web_engine_get_layout_mode (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_layout_mode (self);
}

void
g_web_engine_set_load_images (GWebEngine *self, GWebEngineImagePolicy level)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_load_images (self, level);
}

GWebEngineImagePolicy
g_web_engine_get_load_images (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_load_images (self);
}

void
g_web_engine_set_frame_stacking (GWebEngine *self, gboolean enabled)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_frame_stacking (self, enabled);
}

gboolean
g_web_engine_get_frame_stacking (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_stacking (self);
}

GWebStatus
g_web_engine_save_web_page (GWebEngine *self, GWebEngineSaveAction setting, const gchar *file_name_with_path)
{
	return G_WEB_ENGINE_GET_CLASS (self)->save_web_page (self, setting, file_name_with_path);
}

GWebStatus
g_web_engine_save_current_frame (GWebEngine *self, GWebEngineSaveAction setting, const gchar *file_name_with_path)
{
	return G_WEB_ENGINE_GET_CLASS (self)->save_current_frame (self, setting, file_name_with_path);
}

gchar*
g_web_engine_get_frame_title (GWebEngine *self, gint frame_number)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_title (self, frame_number);
}

gchar* 
g_web_engine_get_element_details (GWebEngine *self, gint type)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_element_details (self, type);
}

gint
g_web_engine_get_frame_number (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_frame_number (self);
}

GWebStatus
g_web_engine_save_web_page_image (GWebEngine *self, const gchar *url, const gchar* directory)
{
	return G_WEB_ENGINE_GET_CLASS (self)->save_web_page_image (self, url, directory);
}

void
g_web_engine_select_all_text (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->select_all_text (self);
}

void
g_web_engine_set_language_encoding (GWebEngine *self, GWebEngineEncoding encoding)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_language_encoding (self, encoding);
}

void
g_web_engine_set_frame_encoding (GWebEngine *self, GWebEngineEncoding encoding)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_frame_encoding (self, encoding);
}

gboolean
g_web_engine_find_text (GWebEngine *self, const gchar *string, gboolean reverse, gboolean whole_word, gboolean case_sensitive, gboolean restart)
{
	return G_WEB_ENGINE_GET_CLASS (self)->find_text (self, string, reverse, whole_word, case_sensitive, restart);
}

GWebEngineSearchResult
g_web_engine_type_find_text (GWebEngine *self, const gchar *string, gboolean reverse, gboolean case_sensitive, gboolean restart)
{
    return G_WEB_ENGINE_GET_CLASS (self)->type_find_text (self, string, reverse, case_sensitive, restart);
}

void
g_web_engine_authenticate (GWebEngine *self, gboolean ok, const gchar *username, const gchar *password)
{
	G_WEB_ENGINE_GET_CLASS (self)->authenticate (self, ok, username, password);
}

GWebStatus
g_web_engine_cut (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->cut (self);
}

GWebStatus
g_web_engine_copy (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->copy (self);
}

GWebStatus
g_web_engine_paste (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->paste (self);
}

gboolean
g_web_engine_can_cut (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_cut (self);
}

gboolean
g_web_engine_can_paste (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_paste (self);
}

gboolean
g_web_engine_can_copy (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_copy (self);
}

gboolean
g_web_engine_can_selecttext (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->can_selecttext (self);
}

gchar*
g_web_engine_get_favicon_name (GWebEngine *self, const gchar *favicon_folder)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_favicon_name (self, favicon_folder);
}

GObject*
g_web_engine_get_engine_widget (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_engine_widget (self);
}

GObject*
g_web_engine_get_engine_notifier (GWebEngine *self)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_engine_notifier (self);
}

void
g_web_engine_set_open_link_mode (GWebEngine *self, gboolean in_new_window)
{
	G_WEB_ENGINE_GET_CLASS (self)->set_open_link_mode (self, in_new_window);
}

GWebStatus
g_web_engine_set_true_zoom_mode (GWebEngine *self, gboolean status)
{
	return G_WEB_ENGINE_GET_CLASS (self)->set_true_zoom_mode (self, status);
}

void
g_web_engine_notify_plugins (GWebEngine *self, gint event)
{
	G_WEB_ENGINE_GET_CLASS (self)->notify_plugins (self, event);
}

void
g_web_engine_preload_current_skin (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->preload_current_skin (self);
}
void
g_web_engine_invoke_selectmatch (GWebEngine *self)
{
	G_WEB_ENGINE_GET_CLASS (self)->invoke_selectmatch (self);
}

GArray*
g_web_engine_get_server_certificate (GWebEngine *self, gpointer context)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_server_certificate (self, context);
}

gchar* 
g_web_engine_get_page_verifier_name( GWebEngine *self )
{
    return G_WEB_ENGINE_GET_CLASS (self)->get_page_verifier_name (self);
}

gboolean
g_web_engine_permit_page_unload (GWebEngine *self)
{
    return G_WEB_ENGINE_GET_CLASS (self)->permit_page_unload (self);
}



gboolean 
g_web_engine_get_thumbnail (GWebEngine *self, const gchar* thumbnail_filename, gint width, gint height)
{
	return G_WEB_ENGINE_GET_CLASS (self)->get_thumbnail (self, thumbnail_filename, width, height );
}

gint
g_web_engine_get_text_zoom_level(GWebEngine *self)
{
    return G_WEB_ENGINE_GET_CLASS(self)->get_text_zoom_level(self);
}

void
g_web_engine_set_text_zoom_level(GWebEngine *self, gint zoom_level)
{
    G_WEB_ENGINE_GET_CLASS(self)->set_text_zoom_level(self, zoom_level);
}


void 
g_web_engine_enable_shistory_thumbnails (GWebEngine *self, gboolean enable, gint width, gint height)
{
	return G_WEB_ENGINE_GET_CLASS (self)->enable_shistory_thumbnails (self, enable, width, height );
}

void
g_web_engine_update_area (GWebEngine *self, int id, int top, int left, int width, int height, int zoom)
{
	G_WEB_ENGINE_GET_CLASS (self)->update_area (self, id, top, left, width, height, zoom);
}

void
g_web_engine_send_mouse_event (GWebEngine *self, int type, int x, int y, int mod, int button, int clickcount, int time)
{
	G_WEB_ENGINE_GET_CLASS (self)->send_mouse_event (self, type, x, y, mod, button, clickcount, time);
}

gboolean 
g_web_engine_evaluate_js (GWebEngine *self, const gchar* js)
{
	return G_WEB_ENGINE_GET_CLASS (self)->evaluate_js (self, js );
}
